Exception: SvgSentinel::Error
- Inherits:
-
StandardError
- Object
- StandardError
- SvgSentinel::Error
- Defined in:
- lib/svg_sentinel/errors.rb
Overview
Base class for all errors this library raises deliberately.
Base class for all errors this library raises deliberately.